summaryrefslogtreecommitdiffstats
path: root/src/structures
diff options
context:
space:
mode:
authorDenis Isidoro <denisidoro@users.noreply.github.com>2020-08-29 18:58:55 -0300
committerGitHub <noreply@github.com>2020-08-29 18:58:55 -0300
commite61e588b82a62cfb7fea9ffea4f99d91a8600abe (patch)
tree8e1aa7870db2ad6f9a9037eb56e3a19b92e669ce /src/structures
parentd79f181b4df80c1bf56f86bd6c49a0f754364e8c (diff)
Improve documentation (#395)v2.10.0
Diffstat (limited to 'src/structures')
-rw-r--r--src/structures/config.rs28
1 files changed, 16 insertions, 12 deletions
diff --git a/src/structures/config.rs b/src/structures/config.rs
index ea7759e..2d775f5 100644
--- a/src/structures/config.rs
+++ b/src/structures/config.rs
@@ -17,17 +17,21 @@ fn parse_finder(src: &str) -> Result<FinderChoice, Error> {
Please refer to https://github.com/denisidoro/navi
EXAMPLES:
- navi # default behavior
- navi --print # doesn't execute the snippet
- navi --path '/some/dir:/other/dir' # uses custom cheats
- navi query git # filters results by "git"
- navi best 'sql create db' # uses a snippet as a CLI
- navi repo add denisidoro/cheats # imports cheats from github.com/denisidoro/cheats
- source <(navi widget zsh) # loads the zsh widget
- navi --finder 'skim' # set which finder is supposed to be used (fzf [default] / skim)
- navi --fzf-overrides '--with-nth 1,2' # shows only the comment and tag columns
- navi --fzf-overrides '--nth 1,2' # search will consider only the first two columns
- navi --fzf-overrides '--no-exact' # looser search algorithm"#)]
+ navi # default behavior
+ navi --print # doesn't execute the snippet
+ navi --tldr docker # search for docker cheatsheets using tldr
+ navi --cheatsh docker # search for docker cheatsheets using cheatsh
+ navi --path '/some/dir:/other/dir' # uses .cheat files from custom paths
+ navi --query git # filters results by "git"
+ navi 'create db' --best-match # uses a snippet as a CLI
+ name=mydb navi 'create db' --best-match # same, but set the value for the <name> variable
+ navi repo add denisidoro/cheats # imports cheats from a git repository
+ source <(navi widget zsh) # loads the zsh widget
+ navi --finder 'skim' # set skim as finder, instead of fzf
+ navi --fzf-overrides '--with-nth 1,2' # shows only the comment and tag columns
+ navi --fzf-overrides '--no-select-1' # prevents autoselection in case of single line
+ navi --fzf-overrides '--nth 1,2' # search will consider only the first two columns
+ navi --fzf-overrides '--no-exact' # looser search algorithm"#)]
#[structopt(setting = AppSettings::ColorAuto)]
#[structopt(setting = AppSettings::ColoredHelp)]
#[structopt(setting = AppSettings::AllowLeadingHyphen)]
@@ -160,7 +164,7 @@ fn deprecated(syntax: &str) {
return;
}
eprintln!(
- r"⚠️ The following syntax has been DEPRECATED:
+ r"⚠️ The following syntax has been DEPRECATED:
navi {}
Please check `navi --help` for more info on how to achieve the same result with the new syntax.